@@ -11,4 +11,9 @@ task_list = [
 if 'milestone_5_p1.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_5_p1.txt')
     if len(errors) != 0:
-        mark_incomplete(task1_id, errors['test_presence_milestone_5'])
\ No newline at end of file
+        if 'test_presence_milestone_5' in errors:
+            mark_incomplete(task1_id, errors['test_presence_milestone_5'])
+        elif 'test_play_game' in errors:
+            mark_incomplete(task1_id, errors['test_play_game'])
+        elif 'test_presence_class' in errors:
+            mark_incomplete(task1_id, errors['test_presence_class'])
\ No newline at end of file
